import React, { Component } from "react";
import { pdfjs } from "react-pdf";
import "react-pdf/dist/esm/Page/AnnotationLayer.css";
import "../style/react_pdf_viewer.css";
import { NormalizedPosition, Position } from "../types";
export declare type Coords = {
    x: number;
    y: number;
};
export declare type TextSelectionType = {
    text: string;
    position: Position;
};
export declare type AreaSelectionType = {
    image: string;
    position: Position;
};
export declare type SelectionType = TextSelectionType | AreaSelectionType;
export declare type NormalizedTextSelection = {
    text: string;
    position: NormalizedPosition;
};
export declare type NormalizedAreaSelection = {
    image: string;
    position: NormalizedPosition;
};
export declare type NormalizedSelection = NormalizedTextSelection | NormalizedAreaSelection;
export declare const isAreaSelection: (selection: SelectionType) => selection is AreaSelectionType;
interface PdfViewerProps {
    url: string;
    selections?: Array<SelectionType>;
    enableAreaSelection?: (event: React.MouseEvent) => boolean;
    onTextSelection?: (highlightTip?: NormalizedTextSelection) => void;
    onAreaSelection?: (highlightTip?: NormalizedAreaSelection) => void;
}
interface PdfViewerState {
    containerWidth?: number;
    textSelectionEnabled: boolean;
    areaSelectionActivePage?: number;
    numPages: number;
}
export declare class PdfViewer extends Component<PdfViewerProps, PdfViewerState> {
    state: PdfViewerState;
    /** Total left and right border width, needed as offset to avoid PageCanvas rendering past right page border. */
    BORDER_WIDTH_OFFSET: number;
    containerDiv: HTMLElement | null;
    selectionMap: {
        [key: number]: SelectionType[];
    } | undefined;
    /**
     * Lifecycle function
     */
    componentDidMount: () => void;
    componentDidUpdate: (nextProps: PdfViewerProps) => void;
    componentWillUnmount: () => void;
    /**
     * Helpers
     */
    resetSelections: () => void;
    computeSelectionMap: () => void;
    setContainerWidth: () => void;
    debouncedSetContainerWidth: () => void;
    /**
     * Text selection handlers
     */
    clearTextSelection: () => void;
    onTextSelectionStart: () => void;
    onTextSelectionChange: () => void;
    /**
     * Area selection handlers
     */
    clearAreaSelection: () => void;
    onAreaSelectionStart: (pageNumber: number) => void;
    onAreaSelectionEnd: (selection: NormalizedAreaSelection) => void;
    /**
     * Event handlers
     */
    onKeyDown: (event: KeyboardEvent) => void;
    onMouseDown: () => void;
    onDocumentLoad: ({ numPages }: pdfjs.PDFDocumentProxy) => void;
    render: () => JSX.Element;
}
export {};
